@@ -24,7 +24,7 @@ class Setting:
                 print("WARNING: Cannot find database at '" + database_name + "'. Creating.")
         self.switch_database(self.database_name)
 
-    def __getitem__(self, item) -> str:
+    def __getitem__(self, item):
         return self.get_setting(text_id=item, detail="value")[0]
 
     def __setitem__(self,
